************************
Authors and contributors
************************

The following people have contributed code and/or ideas to the current version
of Viziphant. The institutional affiliations are those at the time of the
contribution, and may not be the current affiliation of a contributor.

* Björn Müller [1]
* Michael Denker [1]
* Robin Gutzen [1]
* Maximilian Kramer [1]
* Regimantas Jurkus [1]
* Alexander Kleinjohann [1]
* Pietro Quaglio [1]
* Alper Yegenoglu [1]
* Danylo Ulianych [1]
* Alessandra Stella [1]
* Peter Bouss [1]
* Cristiano Köhler [1]
* Simon Essink [1]


1. Institute of Neuroscience and Medicine (INM-6), Computational and Systems Neuroscience & Institute for Advanced Simulation (IAS-6), Theoretical Neuroscience, Jülich Research Centre and JARA, Jülich, Germany


If we've somehow missed you off the list we're very sorry - please let us know.
